@@ -54,7 +54,9 @@ class BaseKRepo(PyProject, spec=KRepoSpec):
 
 
 class KRepo(BaseKRepo):
-    def __init__(self, filepath: Union[str, Path], venv_path: Optional[str] = None) -> None:
+    def __init__(
+        self, filepath: Union[str, Path], venv_path: Optional[str] = None
+    ) -> None:
         super().__init__(filepath, venv_path=venv_path)
         self._workspaces = self.spec.tool.repo.workspaces or {"default": ["./"]}
         self._projects = {project.name: project for project in self.discover_projects()}
@@ -307,6 +309,8 @@ class KRepo(BaseKRepo):
                 if name.startswith(project.name + "--")
             }
             python_version = project_python or repo_python
+            if not python_version:
+                raise RuntimeError("A python version must be specified")
             dependencies[project.name] = ProjectDependencies(
                 repo_dependencies=repo_deps,
                 repo_groups=repo_groups,
@@ -319,13 +323,11 @@ class KRepo(BaseKRepo):
     def get_projects_dependencies_missing(
         self,
     ) -> Tuple[Dict[str, Dict[str, Dependency]], Dict[str, List[str]]]:
-
         missing_deps: Dict[str, Dict[str, Dependency]] = defaultdict(dict)
         # Used like a set
         zombie_deps: Dict[str, Dict[str, None]] = defaultdict(dict)
 
         for project_name in self.projects:
-
             deps_summary = self.get_single_project_dependencies(project_name)
 
             # Iterate over groups
@@ -360,7 +362,6 @@ class KRepo(BaseKRepo):
                         zombie_deps[repo_group_name][dep] = None
 
             for dep, dep_spec in deps_summary.dependencies.items():
-
                 if dep in self.projects:
                     continue
 
@@ -442,10 +443,6 @@ class KRepo(BaseKRepo):
                 await self.poetry_add(
                     *packages,
                     group=group,
-                    editable=True if dep.develop else False,
-                    extras=dep.extras,
-                    optional=True if dep.optional else False,
-                    python=dep.python,
                     lock=True,
                 )
 
