@@ -16,6 +16,7 @@ from typing import (
 )
 
 import tomlkit
+import tomlkit.items
 
 from kapla.specs.pyproject import Dependency, PyProjectSpec
 from kapla.wrappers import poetry
@@ -368,7 +369,7 @@ class KPyProject(PyProject):
         filepath: Union[str, Path],
         repo: Optional[KRepo] = None,
         workspace: Optional[str] = None,
-        venv_path: Union[str, Path, None] = None
+        venv_path: Union[str, Path, None] = None,
     ) -> None:
         super().__init__(filepath, venv_path=repo.venv_path if repo else venv_path)
         self.repo = repo
